pub struct NdncertClient { /* private fields */ }Expand description
A connected NDNCERT client that exchanges protocol messages over the NDN network.
Implementations
Sourceimpl NdncertClient
impl NdncertClient
pub fn new(consumer: Consumer, ca_prefix: Name) -> Self
Sourcepub async fn fetch_ca_profile(&mut self) -> Result<CaProfile, IdentityError>
pub async fn fetch_ca_profile(&mut self) -> Result<CaProfile, IdentityError>
Fetch the CA profile.
Sourcepub async fn enroll(
&mut self,
name: Name,
public_key: Vec<u8>,
validity_secs: u64,
challenge: ChallengeParams,
) -> Result<Certificate, IdentityError>
pub async fn enroll( &mut self, name: Name, public_key: Vec<u8>, validity_secs: u64, challenge: ChallengeParams, ) -> Result<Certificate, IdentityError>
Run the full enrollment exchange and return the issued certificate.